@@ -110,7 +110,7 @@ our %tabletypemariadb =
      'bucardo_test1'  => 'SMALLINT',
      'bucardo_test2'  => 'INT',
      'Bucardo_test3'  => 'BIGINT',
-     'bucardo_test4'  => 'VARCHAR(1000)',
+     'bucardo_test4'  => 'VARCHAR(700)',
      'bucardo_test5'  => 'DATE',
      'bucardo_test6'  => 'DATETIME',
      'bucardo_test7'  => 'NUMERIC(5,1)',
@@ -151,7 +151,7 @@ our %tabletypesqlite =
      );
 
 
-our @tables2empty = (qw/droptest/);
+our @tables2empty = (qw/droptest_bucardo/);
 
 our %sequences =
     (
@@ -749,13 +749,13 @@ sub add_test_schema {
     my ($tcount,$scount,$fcount) = (0,0,0);
 
     ## Empty out or create the droptest table
-    if (table_exists($dbh => 'droptest')) {
-        $dbh->do('TRUNCATE TABLE droptest');
+    if (table_exists($dbh => 'droptest_bucardo')) {
+        $dbh->do('TRUNCATE TABLE droptest_bucardo');
     }
     else {
         $tcount++;
         $dbh->do(q{
-            CREATE TABLE droptest (
+            CREATE TABLE droptest_bucardo (
               name TEXT NOT NULL,
               type TEXT NOT NULL
             )
@@ -776,7 +776,7 @@ sub add_test_schema {
                 RETURNS trigger
                 LANGUAGE plpgsql
                 AS $_$ BEGIN
-                INSERT INTO droptest(name,type)
+                INSERT INTO droptest_bucardo(name,type)
                     VALUES (TG_RELNAME, 'trigger');
                 RETURN NULL;
                 END;
@@ -790,7 +790,7 @@ sub add_test_schema {
                 RETURNS trigger
                 LANGUAGE plpgsql
                 AS $_$ BEGIN
-                INSERT INTO droptest(name,type)
+                INSERT INTO droptest_bucardo(name,type)
                     VALUES (TG_RELNAME, 'trigger');
                 RETURN NULL;
                 END;
@@ -849,7 +849,7 @@ sub add_test_schema {
         $SQL = qq{
             CREATE OR REPLACE RULE "bcrule_$table"
             AS ON INSERT TO "$table"
-            DO ALSO INSERT INTO droptest(name,type) VALUES ('$table','rule')
+            DO ALSO INSERT INTO droptest_bucardo(name,type) VALUES ('$table','rule')
             };
         $table =~ /0/ and $SQL =~ s/NEW.inty/0/;
         $dbh->do($SQL);
@@ -1929,6 +1929,7 @@ sub check_sequences_same {
             ## Compare certain items
             for my $item (qw/ last_value start_value increment_by min_value max_value is_cycled is_called/) {
                 my ($uno,$dos) = ($firstone{$seq}->{$item}, $info->{$item});
+                next if ! defined $uno or ! defined $dos;
                 if ($uno ne $dos) {
                     push @msg, "$item is different on $firstdb vs $dbname: $uno vs $dos";
                 }
